@@ -14,7 +14,7 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-enable_logging = True
+enable_logging = False
 
 if enable_logging:
     fd = open('/tmp/openvpn-applet.log','w+')
@@ -189,13 +189,7 @@ class vpn_control():
         return vpn_conf        
         
     def __init__(self):
-        self.vpn_list = []
-        for v in self.read_vpn_conf('/etc/openvpn',['conf','ovpn']):
-            log(v)
-            self.vpn_list.append(vpn(v))
-        for v in self.read_vpn_conf('/home/user/.openvpn-applet',['conf','ovpn']):
-            log(v)
-            self.vpn_list.append(vpn(v,'/home/user/.openvpn-applet'))
+        self.update()
     
     def __str__(self):
         s = ''
@@ -205,6 +199,15 @@ class vpn_control():
             s = s+str(i+1)+'. '+v.name+' - '+cmd+'\n'
         return s   
 
+    def update(self):
+        self.vpn_list = []
+        for v in self.read_vpn_conf('/etc/openvpn',['conf','ovpn']):
+            log(v)
+            self.vpn_list.append(vpn(v))
+        for v in self.read_vpn_conf('/home/user/.openvpn-applet',['conf','ovpn']):
+            log(v)
+            self.vpn_list.append(vpn(v,'/home/user/.openvpn-applet'))
+
     def start(self, index,user=None,passwd=None,enable_log=False):
         self.vpn_list[index].start(user,passwd)
         
@@ -235,6 +238,12 @@ class vpn_control():
             if v.get_status(): active = active + 1
         return active
 
+    def get_vpn_name(self, number):
+        return self.vpn_list[number].get_name()
+
+    def get_conf_file(self, number):
+        return self.vpn_list[number].get_conf_file()
+
     
 class openvpn_applet(hildondesktop.StatusMenuItem):
     def __init__(self):
@@ -258,16 +267,6 @@ class openvpn_applet(hildondesktop.StatusMenuItem):
         #self.button = gtk.Button("OpenVPN");
         self.button.connect("clicked", self.button_clicked_event)
         
-        textcell = gtk.CellRendererText()
-        imagecell = gtk.CellRendererPixbuf()
-        
-        self.combo = gtk.ComboBox()
-        self.combo.pack_start(imagecell, True)
-        self.combo.pack_start(textcell, True)
-        self.combo.add_attribute(imagecell, 'stock-id',3)
-        self.combo.add_attribute(textcell, 'text', 0)
-        self.combo.connect("changed", self.combo_changed_event)
-
         self.add(self.button)
         self.show_all()
         self.update_list()
@@ -276,63 +275,14 @@ class openvpn_applet(hildondesktop.StatusMenuItem):
         #self.connect("show-settings", self.open_settings)
      
     def update_list(self,source=None):
-        vpn_list = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING,gobject.TYPE_PYOBJECT,gobject.TYPE_STRING,gobject.TYPE_BOOLEAN)
-        self.vc = vpn_control()
-        if len(self.vc.vpn_list) == 0:
-            #vpn_list.insert(0,("No Connections", "",None,None))
-            pass
+        if self.vc == None:
+            self.vc = vpn_control()
         else:
-            for i,v in enumerate(self.vc.vpn_list):
-                if v.get_status():
-                    icon = gtk.STOCK_YES
-                else:
-                    icon = gtk.STOCK_NO
-                vpn_list.insert(i,(v.get_name(), v.get_conf_file(),v,icon,True))
-                #self.combo.insert_text(i,v.name)
+            self.vc.update()
 
-        self.combo.set_model(vpn_list)
-        if source == None:
-            self.set_options_visible(True)
-            self.combo.set_active(0)
-
-        
-        if self.vc.get_vpn_count() > 0:
-            self.combo.set_active(0)
-        #self.frame.check_resize()
-
-    def set_options_visible(self,available):
-        model = self.combo.get_model()
-        iter = model.get_iter_first()
-        if iter == None:
-            if available == True:
-                model.append(("Options...",None,None,None,False))
-        else:    
-            while model.iter_next(iter) != None:
-                iter = model.iter_next(iter)
-    
-            if available == True:
-                if model.get_value(iter,4) == True:
-                    model.append(("Options...",None,None,None,False))
-            else:
-                if model.get_value(iter,4) == False:
-                    model.remove(iter)            
-    
     def get_vpn_list(self):
         return self.combo.get_model()
         
-    def combo_changed_event(self,widget):
-        index = self.combo.get_active()
-        if index >= 0:
-            if index == self.vc.get_vpn_count():
-                #self.button.set_label("Open")
-                pass
-            elif self.vc.status(index) == False:
-                #self.button.set_label("Start")
-                pass
-            else:
-                #self.button.set_label("Stop")
-                pass
-    
     def button_clicked_event(self,widget):
         dlg = SelectConnectionDialog(parent=None,vpn_manager=self.vc)            
         dlg.connect("response",self.manage_connection)
@@ -362,12 +312,12 @@ class openvpn_applet(hildondesktop.StatusMenuItem):
         return widget
         
     def open_settings(self, widget=None, data=None):
-        self.set_options_visible(False)
-        dlg = OpenvpnAppletSettings(model=self.combo.get_model(), applet=self)
+        #self.set_options_visible(False)
+        dlg = OpenvpnAppletSettings(vpn_manager=self.vc)
         dlg.run()
         dlg.destroy()
-        self.set_options_visible(True)
-        self.combo.set_active(0)
+        #self.set_options_visible(True)
+        #self.combo.set_active(0)
         self.update_button()
 
     def manage_connection(self, widget, vpn_number):
@@ -378,9 +328,9 @@ class openvpn_applet(hildondesktop.StatusMenuItem):
         if vpn_number >= 0  and vpn_number < self.vc.get_vpn_count():
             if self.vc.status(vpn_number) == False:
                 if self.vc.user_required(vpn_number) and self.vc.pass_required(vpn_number):
-                    (user,passwd,cont) = self.user_pass_dlg(True)
+                    (user,passwd,cont) = user_pass_dlg(True)
                 elif self.vc.pass_required(vpn_number):
-                    (user,passwd,cont) = self.user_pass_dlg(False)
+                    (user,passwd,cont) = user_pass_dlg(False)
                 else:
                     user   = None
                     passwd = None
@@ -397,26 +347,26 @@ class openvpn_applet(hildondesktop.StatusMenuItem):
             print "open settings"
             self.open_settings(self)
 
-    def user_pass_dlg(self,ask_passwd):
-        if ask_passwd:
-            dlg = hildon.LoginDialog(gtk.Window())
-            dlg.set_message("Openvpn Authentication")
-            response = dlg.run()
-            user_pass_resp = (dlg.get_username(),dlg.get_password())
-            dlg.destroy()
-        else:
-            dlg = hildon.GetPasswordDialog(gtk.Window(),False)
-            dlg.set_message("Openvpn Authentication")
-            response = dlg.run()
-            user_pass_resp = (None,dlg.get_password())
-            dlg.destroy()
+def user_pass_dlg(ask_passwd):
+    if ask_passwd:
+        dlg = hildon.LoginDialog(gtk.Window())
+        dlg.set_message("Openvpn Authentication")
+        response = dlg.run()
+        user_pass_resp = (dlg.get_username(),dlg.get_password())
+        dlg.destroy()
+    else:
+        dlg = hildon.GetPasswordDialog(gtk.Window(),False)
+        dlg.set_message("Openvpn Authentication")
+        response = dlg.run()
+        user_pass_resp = (None,dlg.get_password())
+        dlg.destroy()
 
-        if response == gtk.RESPONSE_OK:
-            user_pass_resp = (user_pass_resp[0],user_pass_resp[1],True)
-        else:
-            user_pass_resp = (user_pass_resp[0],user_pass_resp[1],False)
+    if response == gtk.RESPONSE_OK:
+        user_pass_resp = (user_pass_resp[0],user_pass_resp[1],True)
+    else:
+        user_pass_resp = (user_pass_resp[0],user_pass_resp[1],False)
 
-        return user_pass_resp
+    return user_pass_resp
 
 class SelectConnectionDialog(gtk.Dialog):
     def __init__(self,title="Select OpenVPN Connection", parent=None, flags=0, buttons=None,vpn_manager=None):
@@ -452,46 +402,41 @@ class SelectConnectionDialog(gtk.Dialog):
         self.destroy()
 
 class OpenvpnAppletSettings(gtk.Dialog):
-    def __init__(self,title="Openvpn connections", parent=None, flags=0, buttons=None, model=None, applet=None):
+    def __init__(self,title="Openvpn connections", parent=None, flags=0, buttons=None, vpn_manager=None, applet=None):
         gtk.Dialog.__init__(self,title, parent, flags, buttons)
 
-        self.model = model
+        self.vpn_manager = vpn_manager
+        self.selection = None
+        self.update_selection()
 
-        
-        self.applet = applet
-        
-        self.treeview = gtk.TreeView(self.model)
-        self.vpncolumn = gtk.TreeViewColumn('Openvpn Connection')
-        self.treeview.append_column(self.vpncolumn)
-        self.cell = gtk.CellRendererText()
-        self.vpncolumn.pack_start(self.cell, True)
-        self.vpncolumn.add_attribute(self.cell, 'text', 0)
-
-        self.new_button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL,"New")
+        self.new_button = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL,"New")
         self.new_button.connect("clicked", self.open_new_dialog)
         self.delete_button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL,"Delete")
         self.delete_button.connect("clicked", self.delete_clicked_event)
-        #self.disable_button = gtk.Button("Disable")
-        #self.disable_button.connect("clicked", self.disable_clicked_event)
         self.test_button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL,"Test")
         self.test_button.connect("clicked", self.test_clicked_event)
 
-
-        self.treeview.set_size_request(-1, 155)
-        scrolledwindow = gtk.ScrolledWindow()
-        scrolledwindow.set_policy(gtk.POLICY_AUTOMATIC,gtk.POLICY_AUTOMATIC)
-        scrolledwindow.add(self.treeview)
-        hbox = gtk.HBox()
-        hbox.pack_start(scrolledwindow)
-        self.vbox.pack_start(hbox)   
+        self.selection.set_size_request(-1, 155)
         self.action_area.pack_start(self.new_button)
         self.action_area.pack_start(self.delete_button)
         self.action_area.pack_start(self.test_button)
         self.add_button("Close", gtk.RESPONSE_CLOSE)
         self.action_area.show_all()
         self.vbox.show_all()
-        
-        
+
+    def update_selection(self):
+        self.vpn_manager.update()
+        if self.selection != None:
+	    self.vbox.remove(self.selection)
+            self.selection.destroy()
+
+        self.selection = hildon.TouchSelector(text = True)
+        self.vbox.pack_start(self.selection)   
+        for i in range(self.vpn_manager.get_vpn_count()):
+            self.selection.insert_text(i,self.vpn_manager.get_vpn_name(i))
+
+	self.vbox.show_all()
+ 
     def open_new_dialog(self, widget, data=None):
         dlg = OpenvpnAppletNewConnection()
         response = dlg.run()
@@ -513,7 +458,7 @@ class OpenvpnAppletSettings(gtk.Dialog):
                 for f in files_to_overwrite_message:
                     mstr = mstr+"\n"+f
                 mdlg = gtk.MessageDialog(dlg,0,gtk.MESSAGE_QUESTION,gtk.BUTTONS_NONE,"Overwrite files?\n"+mstr)
-                mdlg.add_buttons("Overwrite", gtk.RESPONSE_ACCEPT,"Don't Overwrite", gtk.RESPONSE_REJECT)
+                mdlg.add_buttons("Overwrite", gtk.RESPONSE_ACCEPT,"Don't Overwrite", gtk.RESPONSE_NONE)
                 response = mdlg.run()
                 mdlg.destroy()
                 if response == gtk.RESPONSE_ACCEPT:
@@ -522,26 +467,23 @@ class OpenvpnAppletSettings(gtk.Dialog):
                 files_to_copy = all_files
                         
             copy_file(files_to_copy)
-            self.applet.update_list(self)
-            self.treeview.set_model(self.applet.get_vpn_list())
+            self.update_selection()
         dlg.destroy()
 
     def delete_clicked_event(self, widget, data=None):
         log("delete_clicked_event")
         file_links = FileLinks("/etc/openvpn", ["conf", "ovpn"])
-        selection = self.treeview.get_selection()
-        selection.set_mode(gtk.SELECTION_SINGLE)
-        (model, iter) = selection.get_selected()
-        if iter != None:
+        vpn_number = self.selection.get_active(0)
+        if vpn_number >= 0:
             log("Item selected")
-            filename = model.get_value(iter,1)
+            filename = self.vpn_manager.get_conf_file(vpn_number)
             log(filename)
             log(file_links[filename])
             mstr = filename
             for f in file_links[filename]:
                 mstr += "\n"+str(f)
             dlg = gtk.MessageDialog(self,0,gtk.MESSAGE_QUESTION,gtk.BUTTONS_NONE,"Deleting files:\n"+mstr)
-            dlg.add_buttons("Delete", gtk.RESPONSE_ACCEPT,"Cancel", gtk.RESPONSE_REJECT)
+            dlg.add_buttons("Delete", gtk.RESPONSE_ACCEPT,"Cancel", gtk.RESPONSE_NONE)
             response = dlg.run()
             dlg.destroy()
             if response == gtk.RESPONSE_ACCEPT:
@@ -550,23 +492,17 @@ class OpenvpnAppletSettings(gtk.Dialog):
         else:
             log("No selection")
 
-        self.applet.update_list(self)
-        self.treeview.set_model(self.applet.get_vpn_list())
+        self.update_selection()
         
-    def disable_clicked_event(self, widget, data=None):
-        pass
-    
     def test_clicked_event(self,widget,data=None):
-        selection = self.treeview.get_selection()
-        selection.set_mode(gtk.SELECTION_SINGLE)
-        (model, iter) = selection.get_selected()
-        if iter != None:
+        vpn_number = self.selection.get_active(0)
+        if vpn_number >= 0:
             log("Item selected")
-            vpn = model.get_value(iter,2)
+            vpn = self.vpn_manager.vpn_list[vpn_number]
             if vpn.user_required() and vpn.pass_required():
-                (user,passwd,cont) = self.applet.user_pass_dlg(True)
+                (user,passwd,cont) = user_pass_dlg(True)
             elif vpn.pass_required():
-                (user,passwd,cont) = self.applet.user_pass_dlg(False)
+                (user,passwd,cont) = user_pass_dlg(False)
             else:
                 user   = None
                 passwd = None
@@ -646,8 +582,6 @@ class OpenvpnAppletNewConnection(gtk.Dialog):
         gtk.Dialog.__init__(self,title, parent, flags, buttons)
 
         self.extra_files = []
-        self.check = {}
-        self.file_entry = {}
         self.browse_button = {}
 
         self.add_button("Import",gtk.RESPONSE_OK)
@@ -664,16 +598,11 @@ class OpenvpnAppletNewConnection(gtk.Dialog):
         for i,d in enumerate(description_keys):
             log(d)
             hbox = gtk.HBox()
-            self.file_entry[descriptions[d]] = gtk.Entry()
             self.browse_button[descriptions[d]] = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL,d, "None")
             self.browse_button[descriptions[d]].set_alignment(0.0,0.5,1,1)
             self.browse_button[descriptions[d]].set_style(hildon.BUTTON_STYLE_PICKER)
-            #hbox.pack_start(self.file_entry[descriptions[d]])
             hbox.pack_start(self.browse_button[descriptions[d]])           
-            self.check[descriptions[d]] = gtk.CheckButton(d)
-            self.browse_button[descriptions[d]].connect("clicked", self.browse_button_event, (self.file_entry[descriptions[d]], self.check[descriptions[d]]))   
-
-            #table.attach(self.check[descriptions[d]],0,1,i,i+1)
+            self.browse_button[descriptions[d]].connect("clicked", self.browse_button_event, None)   
             table.attach(hbox,1,2,i,i+1)   
             vbox2.pack_start(table)
 
@@ -699,14 +628,10 @@ class OpenvpnAppletNewConnection(gtk.Dialog):
         return files
     
     def browse_button_event(self, widget, data=None):
-        textentry = data[0]
-        checkbox = data[1]
         dlg = hildon.FileChooserDialog(self, gtk.FILE_CHOOSER_ACTION_OPEN, hildon.FileSystemModel())
         response = dlg.run()
         if response == gtk.RESPONSE_OK:
             widget.set_value(dlg.get_filename())
-            textentry.set_text(dlg.get_filename())
-            checkbox.set_active(True)
             filelinks = FileLinks(dlg.get_filename())
             filelinks.filter(['/home','/media'])
             log("Referenced files in",dlg.get_filename(),filelinks)
@@ -714,8 +639,6 @@ class OpenvpnAppletNewConnection(gtk.Dialog):
                 log("Keyword",f,filelinks.get_matchword(f))
                 try:
                     self.browse_button[filelinks.get_matchword(f)].set_value(f)
-                    self.file_entry[filelinks.get_matchword(f)].set_text(f)
-                    self.check[filelinks.get_matchword(f)].set_active(True)
                     log("Keyword file:",filelinks.get_matchword(f),f)
                 except KeyError:
                     self.extra_files.append(f)
